# Python Cloudrock Client

Python API client for [backend](https://github.com/kubeworkz/cloudrock-metal) of [Cloudrock project](https://cloudrock.ca/).

## Contributing

Install `pre-commit`

```bash
pip install pre-commit
pre-commit install
```
